# Code of Conduct

This project adheres to the Contributor Covenant Code of Conduct.

We are committed to providing a welcoming and inclusive experience for everyone.
Harassment, discrimination, or abusive behavior will not be tolerated.

For full details, see:
https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
